@@ -26,6 +26,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <locale.h>		/* setlocale() */
 
 /*
  * Compiling against IDN enabled Libc:
@@ -50,6 +51,8 @@ main(int argc, char *argv[])
   struct addrinfo *res = NULL;
   int rc;
 
+  setlocale (LC_ALL, "");
+
   //printf("locale charset `%s'\n", stringprep_locale_charset());
 
   memset(&hints, 0, sizeof(hints));
@@ -62,6 +65,7 @@ main(int argc, char *argv[])
   else if (res)
     printf("address `%s'\ncanonical name `%s'\n",
 	   res->ai_addr ?
+	   /* FIXME: Use inet_ntop, so it works for IPv6 too. */
 	   inet_ntoa(((struct sockaddr_in*)res->ai_addr)->sin_addr) : "ERROR",
 	   res->ai_canonname ? res->ai_canonname : "ERROR");
   else
